********************************************************************************
* Figure 8: Intergenerational educational mobility in LAC - gender
********************************************************************************
use "${path}\Output\dta\LAC_clean_gender", clear
gen gap_up=(country_beta_up_male - country_beta_up_female)
gen gap_down=(country_beta_down_male - country_beta_down_female)
keep country cohort gap_up gap_down
destring cohort, replace

bys country: egen aux1=count(cohort) if inrange(cohort,1950,1980)
g aux= aux1==4
tab country if aux==1
drop aux1

reg gap_up cohort if aux==1
local beta= _b[_cons]
mat table = r(table)
local beta0 = round(table[1,2], .001)
local se0 = round(table[2,2], .0001)
local beta1 = round(table[1,1], .0001)
local se1 = round(table[2,1], .0001)
set scheme s1color

label define country3 32 "ARG" 68 "BOL" 76 "BRA" 152 "CHL" 170 "COL" 188 "CRI" 214 "DOM" 218 "ECU" 222 "SLV" 320 "GTM" 332 "HTI" 340 "HND" 388 "JAM" 484 "MEX" 558 "NIC" 591 "PAN" 600 "PRY" 604 "PER" 662 "LCA" 858 "URY" 862 "VEN"
label values country country3

twoway (scatter gap_up cohort if aux==1, msymbol(Dh) mlabel(country) /*mlabsize(*0.5)*/ mlabposition(2) msize(*0.1) ///
ytitle("male upward IGM - female upward IGM") xtitle("Birth decade")) ///
(scatter gap_up cohort if aux==0, msymbol(S) mlabel(country) /*mlabsize(*0.5)*/ mlabposition(2) msize(*0.1) ///
ytitle("male upward IGM - female upward IGM") xtitle("Birth decade")) ///
(lfit gap_up cohort if aux==1, lpattern(dash)), legend(label(1 countries with data for 1950s, 1960s, 1970s, 1980s) label(2 other countries) label(3 mean among countries with data 1950s-1980s) col(1) pos(6)) ///
text( .23 1968 "gap = `beta0'    +   `beta1'  cohort" ///
"         (`se0')       (`se1')",  box just(left) margin(l+1 t+1 b+1) place(se) width(43) size(3)) aspect(.55) xsize(7) ysize(5) // aspect(0.6)
graph export "${path}\Output\figures\Figure_8a.pdf",replace

reg gap_down cohort if aux==1
local beta= _b[_cons]
mat table = r(table)
local beta0 = round(table[1,2], .001)
display `beta0'
local se0 = round(table[2,2], .0001)
local beta1 = round(table[1,1], .0001)
local se1 = round(table[2,1], .0001)
set scheme s1color
local beta0= "-.8180"
twoway (scatter gap_down cohort if aux==1, msymbol(Dh) mlabel(country) /*mlabsize(*0.5)*/ mlabposition(2) msize(*0.1) ///
ytitle("male downward IGM - female downward IGM") xtitle("Birth decade")) ///
(scatter gap_down cohort if aux==0, msymbol(S) mlabel(country) /*mlabsize(*0.5)*/ mlabposition(2) msize(*0.1) ///
ytitle("male downward IGM - female downward IGM") xtitle("Birth decade")) ///
(lfit gap_down cohort if aux==1, lpattern(dash)), legend(label(1 countries with data for 1950s, 1960s, 1970s, 1980s) label(2 other countries) label(3 mean among countries with data 1950s-1980s) col(1) pos(6)) ///
text( .2 1969 "gap = `beta0'    +   `beta1'  cohort" ///
"        (`se0')       (`se1')",  box just(left) margin(l+1 t+1 b+1) place(se) width(42) size(3)) aspect(.55) xsize(7) ysize(5) // aspect(0.6)
graph export "${path}\Output\figures\Figure_8b.pdf",replace