***********************************************************************************************
*** Table 1: Country-level estimates of educational intergenerational mobility***
***********************************************************************************************
use "${path}\Output\dta\LAC_clean_table1",clear
egen N_14_18=rowtotal(N_14_18_up  N_14_18_down)
egen N_14_25=rowtotal(N_14_25_up  N_14_25_down)
drop if N_14_18==0
drop if N_14_25==0

g years=year
tostring years, replace
bysort country : replace years = years[_n-1] + "," + years if _n > 1
by country : replace years = years[_N]

keep country years country_beta_1 country_beta_2 country_beta_3 country_beta_4 N_14_18 N_14_25

preserve
keep country years
by country: g id=_n
keep if id==1
drop id
tempfile eduold
save `eduold'
restore

gcollapse country_beta_1 country_beta_2 country_beta_3 country_beta_4 N_14_18 N_14_25, by(country)
merge 1:1 country using `eduold'
decode country, gen (countrys)
drop country
order countrys years country_beta_1 country_beta_2 country_beta_3 country_beta_4 N_14_18 N_14_25
gsort -country_beta_1

preserve
gcollapse (mean) country_beta_1 country_beta_2 country_beta_3 country_beta_4 (sum) N_14_18 N_14_25
tempfile updown
save `updown'
restore
append using `updown'
drop _merge
replace years=" " if missing(years)
replace countrys="mean / total" if missing(countrys)

replace country_beta_1=round(country_beta_1, .001)
replace country_beta_2=round(country_beta_2, .001)
replace country_beta_3=round(country_beta_3, .001)
replace country_beta_4=round(country_beta_4, .001)

g Ns_14_18=strofreal(N_14_18, "%13.0gc")
g Ns_14_25=strofreal(N_14_25, "%13.0gc")
drop N_14_18
drop N_14_25

g beta_1=strofreal(country_beta_1)
g beta_2=strofreal(country_beta_2)
g beta_3=strofreal(country_beta_3)
g beta_4=strofreal(country_beta_4)
keep countrys years beta_1 beta_2 beta_3 beta_4 Ns_14_18 Ns_14_25
order countrys years beta_1 beta_2 beta_3 beta_4 Ns_14_18 Ns_14_25
listtab countrys years beta_1 beta_2 beta_3 beta_4 Ns_14_18 Ns_14_25 using "${path}\Output\tables\Table_1.tex", rstyle(tabular) replace